@@ -15,7 +15,7 @@ use List::Compare;
 use List::MoreUtils qw(none uniq firstval);
 use Scalar::Util qw(weaken);
 
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 
 my %translation = (
 	2  => 'Polizeiliche Ermittlung',
@@ -98,7 +98,7 @@ my %translation = (
 );
 
 Travel::Status::DE::IRIS::Result->mk_ro_accessors(
-	qw(arrival classes date datetime delay departure is_cancelled is_transfer
+	qw(arrival date datetime delay departure is_cancelled is_transfer
 	  is_unscheduled is_wing line_no old_train_id old_train_no platform raw_id
 	  realtime_xml route_start route_end
 	  sched_arrival sched_departure sched_platform sched_route_start
@@ -410,6 +410,14 @@ sub canceled_stops {
 		[ $self->{comparator}->get_unique ] );
 }
 
+sub classes {
+	my ($self) = @_;
+
+	my @classes = split(//, $self->{classes});
+
+	return @classes;
+}
+
 sub merge_with_departure {
 	my ( $self, $result ) = @_;
 
@@ -736,7 +744,7 @@ arrival/departure received by Travel::Status::DE::IRIS
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 DESCRIPTION
 
