@@ -26,7 +26,7 @@ use Text::LevenshteinXS qw(distance);
 
 # TODO switch to Text::Levenshtein::XS once AUR/Debian packages become available
 
-our $VERSION = '1.05';
+our $VERSION = '1.09';
 
 my @stations = (
 EOF
@@ -68,6 +68,8 @@ while ( my $line = <STDIN> ) {
 	$station =~ s{ ^ KDFFH    $ }{KDFF}x;
 	$station =~ s{ ^ KDN \s P $ }{KDN}x;
 	$station =~ s{ ^ KRY \s P $ }{KRY}x;
+	$station =~ s{ ^ TS \s\s T$ }{TST}x;
+	$station =~ s{ ^ TSZ \s F $ }{TSFE}x;
 
 	printf(
 		"\t['%s','%s',%s,%s,%s],\n",
@@ -1943,7 +1945,7 @@ Travel::Status::DE::IRIS::Stations - Station name to station code mapping
 
 =head1 VERSION
 
-version 0.00
+version 1.09
 
 =head1 DESCRIPTION
 
@@ -2053,6 +2055,6 @@ Lookup code: Copyright (C) 2014-2016 by Daniel Friesel E<lt>derf@finalrewind.org
 
 This module is licensed under the same terms as Perl itself. Note that the
 station data used by this module is also available under a CC-BY 4.0 license on
-L<http://data.deutschebahn.com/datasets/haltestellen/>.
+L<http://data.deutschebahn.com/dataset/data-haltestellen>.
 
 EOF
